@@ -24,7 +24,7 @@
 
       ! end subroutine marq98j_scl
 
-      ! subroutine derivaj(b,m,v,rl,k0,fctnames,individu)
+      ! subroutine derivaJ_scl(b,m,v,rl,k0,fctnames,individu)
         ! integer, intent(in)::individu
         ! integer,intent(in)::m
     ! double precision,dimension(2)::k0
@@ -32,9 +32,9 @@
         ! double precision,dimension(m),intent(in)::b
         ! double precision,dimension((m*(m+3)/2)),intent(out)::v
     ! double precision,external::fctnames
-      ! end subroutine derivaj
+      ! end subroutine derivaJ_scl
 
-      ! subroutine searpasj(vw,step,b,bh,m,delta,fim,k0,fctnames,individu)
+      ! subroutine searpasj_scl(vw,step,b,bh,m,delta,fim,k0,fctnames,individu)
         ! integer, intent(in)::individu
         ! integer,intent(in)::m
     ! double precision,dimension(2)::k0
@@ -42,16 +42,16 @@
         ! double precision,dimension(m),intent(inout)::bh,delta
         ! double precision,intent(inout)::vw,fim,step
     ! double precision,external::fctnames
-      ! end subroutine searpasj
+      ! end subroutine searpasj_scl
 
-      ! subroutine dmfsdj(a,n,eps,ier)
+      ! subroutine dmfsdj_scl(a,n,eps,ier)
         ! integer,intent(in)::n
         ! integer,intent(inout)::ier
         ! double precision,intent(inout)::eps 
         ! double precision,dimension(n*(n+1)/2),intent(inout)::A
-      ! end subroutine dmfsdj
+      ! end subroutine dmfsdj_scl
 
-      ! subroutine valfpaj(vw,fi,b,bk,m,delta,k0,fctnames,individu)
+      ! subroutine valfpaj_scl(vw,fi,b,bk,m,delta,k0,fctnames,individu)
         ! integer, intent(in)::individu
         ! integer,intent(in)::m
     ! double precision,dimension(2)::k0
@@ -60,28 +60,28 @@
         ! double precision,dimension(m),intent(out)::bk
         ! double precision,intent(out)::fi
     ! double precision,external::fctnames
-      ! end subroutine valfpaj
+      ! end subroutine valfpaj_scl
 
-      ! subroutine dmaxt(maxt,delta,m)
+      ! subroutine dmaxt_scl(maxt,delta,m)
         ! integer,intent(in)::m
         ! double precision,dimension(m),intent(in)::delta 
         ! double precision,intent(out)::maxt
-      ! end subroutine dmaxt
+      ! end subroutine dmaxt_scl
       ! end interface verif1
 
       ! interface verif2
-      ! subroutine dsinvj(A,N,EPS,IER)
+      ! subroutine dsinvj_scl(A,N,EPS,IER)
         ! integer,intent(in)::n
         ! integer,intent(inout)::ier
         ! double precision,intent(inout)::eps
         ! double precision,dimension(n*(n+1)/2),intent(inout)::A
-      ! end subroutine dsinvj
+      ! end subroutine dsinvj_scl
 
-      ! subroutine dcholej(a,k,nq,idpos)
+      ! subroutine dcholej_scl(a,k,nq,idpos)
       ! integer,intent(in)::k,nq
       ! integer,intent(inout)::idpos
       ! double precision,dimension(k*(k+3)/2),intent(inout)::a
-      ! end subroutine dcholej
+      ! end subroutine dcholej_scl
       ! end interface verif2
 
       ! end module type
@@ -97,11 +97,11 @@
       implicit none
 ! -Interface permettant la verification des type des arguments
       interface verif1
-        module procedure marq98j_scl,derivaj,searpasj,dmfsdj,valfpaj
+        module procedure marq98j_scl,derivaJ_scl,searpasj_scl,dmfsdj_scl,valfpaj_scl
       end interface verif1
 
       interface verif2
-        module procedure dsinvj,dcholej,dmaxt
+        module procedure dsinvj_scl,dcholej_scl,dmaxt_scl
       end interface verif2
 
       CONTAINS
@@ -121,31 +121,27 @@
 !  1: critere d'arret satisfait (prm=ca, vraisblce=cb, derivee=dd)
 !  2: nb max d'iterations atteints
 !  4: Erreur
-    use residusM,only:indg
-    use parameters
-    use comon,only:t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc, &
-    nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,model, &
-    PEN_deri,Hspl_hess,indic_ALPHA,typeof,indic_eta
+    !use residusM,only:indg	
+    use parameters,only:epsa,epsb,epsd,maxiter
+    use comon,only:nva,model,indic_ALPHA,typeof
+	!t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc,PEN_deri,Hspl_hess, &
+    !nt1dc,nsujet,nva1,nva2,ndate,ndatedc,nst,indic_eta
 
 !add additive
-    use additiv,only:correl
+    !use additiv,only:correl
     use var_surrogate, only:nparamfrail
 
     IMPLICIT NONE
 !   variables globales
 
     ! nouvelles declarations_scl
-    ! double precision,dimension(size(I_hess,1),size(I_hess,2)),intent(out)::I_hess
-    ! double precision,dimension(size(H_hess,1),size(H_hess,2)),intent(out)::H_hess
-    ! double precision,dimension(size(hess,1),size(hess,2)),intent(out)::hess
-    ! double precision,dimension(size(vvv)),intent(out)::vvv
-    integer, intent(in)::individu ! indice de l'individu sur lequel on maximise la vraisemblance
-    double precision,dimension(:,:),intent(inout)::I_hess
-    double precision,dimension(:,:),intent(inout)::H_hess
-    double precision,dimension(:,:),intent(inout)::hess
-    double precision,dimension(:),intent(inout)::vvv
+    integer, intent(in)::m,individu ! indice de l'individu sur lequel on maximise la vraisemblance
+    double precision,dimension(m,m),intent(inout)::I_hess
+    double precision,dimension(m,m),intent(inout)::H_hess
+    double precision,dimension(m,m),intent(inout)::hess
+    double precision,dimension(m*(m+1)/2),intent(inout)::vvv
 
-    integer,intent(in) :: m,effet
+    integer,intent(in) :: effet
     integer,intent(inout)::ni,ier,istop
     double precision,dimension(m*(m+3)/2),intent(out)::v
     double precision,intent(out)::rl
@@ -156,7 +152,7 @@
 !   variables locales
     integer::nql,ii,nfmax,idpos,ncount,id,jd,m1,j,i,ij,k
     double precision,dimension(m*(m+3)/2)::fu,v1,vnonpen
-    double precision,dimension(m)::delta,b1,bh
+    double precision,dimension(:),allocatable::delta,b1,bh ! /scl 21/02/2019 allocation des vecteur pour eviter des probleme lorsqu'on estime un seul parametre 
     double precision::da,dm,ga,tr
     double precision::GHG,step,eps,vw,fi,maxt, &
     z,rl1,th,ep
@@ -165,11 +161,9 @@
 !---------- ajout
     integer::kkk
     
-    ! if(model==10) then
-        ! !print*,"suis la dans Marquard"
-        ! stop
-    ! endif
-    
+	! /scl 21/02/2019 allocation des vecteur pour eviter des probleme lorsqu'on estime un seul parametre 
+	allocate(delta(m),b1(m),bh(m))
+    v=0.d0
     zero=0.d0
     id=0
     jd=0
@@ -187,15 +181,11 @@
     nql=1
     m1=m*(m+1)/2
     ep=1.d-20
-    !!print*,b
-    !!print*,m
-    !stop
-    Main:Do
-        !!print*,"siuis dans main de Marquard"
-        !!print*,b(m-2+1),b(m),b(m-4+1),b(m-4+2)
-!        !print*,b
-        call derivaj(b,m,v,rl,k0,fctnames,individu)
 
+    Main:Do
+
+        call derivaJ_scl(b,m,v,rl,k0,fctnames,individu)	
+		
     rl1=rl
     if(rl.eq.-1.D9) then
         istop=4
@@ -216,8 +206,7 @@
         end do
     end do
     
-        call dsinvj(fu,m,ep,ier)
-    
+        call dsinvj_scl(fu,m,ep,ier)
     if (ier.eq.-1) then ! hessienne non inversible
         !!print*,"here"
         dd=epsd+1.d0
@@ -244,16 +233,6 @@
         !print*,"b(17:22)=",b((m-nparamfrail-2+1):m)
     endif
     
-    !!print*,"suis la model=",model
-    ! if(model==10) !print*,"b=",b 
-    
-!    !print*,"-------------------------"
-!     if (ni.eq.50) then
-!         !print*,"====================> FAUSSE CONVERGENCE"
-!         ca=1.d-5
-!         cb=1.d-5
-!         dd=1.d-5
-!     endif
     if(model.ne.9) then
         !write(*,*)"ligne 225 Optim, critère sur les coefficients: ca=",ca
         !write(*,*)"ligne 226 Optim, critère sur la vraisemblance: cb=",cb
@@ -285,7 +264,7 @@
             endif
         end do
         
-        call dcholej(fu,m,nql,idpos)
+        call dcholej_scl(fu,m,nql,idpos)
 
         if (idpos.ne.0) then
             ncount=ncount+1
@@ -319,18 +298,18 @@
             endif
         endif
 !      !write(6,*) 'loglikelihood not improved '
-        call dmaxt(maxt,delta,m)
+        call dmaxt_scl(maxt,delta,m)
 
         if(maxt.eq.0.D0) then
             vw=th
         else
-            !call dmaxt(maxt,delta,m)
+            !call dmaxt_scl(maxt,delta,m)
             vw=th/maxt
             
         endif
         step=dlog(1.5d0)
 !      !write(*,*) 'searpas'
-        call searpasj(vw,step,b,bh,m,delta,fi,k0,fctnames,individu)
+        call searpasj_scl(vw,step,b,bh,m,delta,fi,k0,fctnames,individu)
         rl=-fi
         if(rl.eq.-1.D9) then
             istop=4
@@ -377,7 +356,7 @@
 !================ pour les bandes de confiance
 !==== on ne retient que les para des splines
 
-    call derivaJ(b,m,v,rl,k0,fctnames,individu)
+   call derivaJ_scl(b,m,v,rl,k0,fctnames,individu)
     if(rl.eq.-1.D9) then
         istop=4
         goto 110
@@ -419,7 +398,7 @@
 
         ep=10.d-10
         !!print*,"v1=",v1,"m1=",m1,"ep=",ep,"ier=",ier,"istop=",istop !scl 22-09-2017
-        call dsinvJ(v1,m1,ep,ier)
+        call dsinvj_scl(v1,m1,ep,ier)
 
         if (ier.eq.-1) then
              !write(*,*)   'echec inversion matrice information pour m1'
@@ -433,7 +412,7 @@
                 hess(i,j)=v1((j-1)*j/2+i)
             end do
         end do
-
+		
         do i=2,m1
             do j=1,i-1
                 hess(i,j)=hess(j,i)
@@ -443,14 +422,14 @@
 
     
     ep=10.d-10
-    call dsinvJ(v,m,ep,ier)
+    call dsinvj_scl(v,m,ep,ier)
     
     if (ier.eq.-1) then
         !write(*,*)   'echec inversion matrice information pur m'
         istop=3
         
 !AD:
-!        call dsinvj(v1,m1,ep,ier)
+!        call dsinvj_scl(v1,m1,ep,ier)
 !        if (ier.eq.-1) then
 !             !write(*,*)'echec inversion matrice information
 !     & prms fixes'
@@ -465,13 +444,16 @@
 
 
     ep=10.d-10
-    call derivaJ(b,m,vnonpen,rl,zero,fctnames,individu)
-    
+   call derivaJ_scl(b,m,vnonpen,rl,zero,fctnames,individu)
+
+   
     do i=1,m
         do j=i,m
             I_hess(i,j)=vnonpen((j-1)*j/2+i)
         end do
     end do
+
+
    
     do i=2,m
         do j=1,i-1
@@ -503,7 +485,8 @@
     end if
        
  110   continue
-
+		deallocate(delta,b1,bh) ! scl_22-09-2017
+		!call dblepr("b(1) sortie Marquard 510", -1, b(1), 1)
        return    
        end subroutine marq98j_scl
 
@@ -511,7 +494,7 @@
 !                          DERIVA
 !------------------------------------------------------------
 
-    subroutine derivaj(b,m,v,rl,k0,fctnames,individu)
+    subroutine derivaJ_scl(b,m,v,rl,k0,fctnames,individu)
     use comon,only:model
     implicit none
     
@@ -519,14 +502,16 @@
     integer,intent(in)::m
     double precision,intent(inout)::rl
     double precision,dimension(2)::k0
-    double precision,dimension(m),intent(in)::b
+    double precision,dimension(m),intent(in)::b ! scl_22-09-2017
     double precision,dimension((m*(m+3)/2)),intent(out)::v
-    double precision,dimension(m)::fcith
-    integer ::i0,m1,ll,i,k,j,iun
+    double precision,dimension(:),allocatable::fcith ! scl_22-09-2017
+    integer ::i0,m1,ll,i,k,j,iun,tail
     double precision::fctnames,thn,th,z,vl,th2,vaux
     external::fctnames
-    
-    !!print*,"suis dans derivaJ, model=",model
+    !call intpr("derivaJ_scl 532", -1, m, 1)
+	allocate(fcith(m)) ! scl_22-09-2017
+	fcith = 0.d0
+    !!print*,"suis dans derivaJ_scl, model=",model
     !stop
     select case(model)
     case(1)
@@ -545,7 +530,7 @@
         th=1.d-3 !surrogate
     end select
 
-    ! !print*,"suis dans derivaJ, model=",model,"th=",th
+    ! !print*,"suis dans derivaJ_scl, model=",model,"th=",th
     
     thn=-th
     th2=th*th
@@ -553,10 +538,11 @@
     i0=0
     iun =1
     !!print*,"debut appel de la vraisamblance dans derrivaJ rl=",rl
+	!call dblepr("b(1)derivaJ_scl 562", -1, b(1), 1)
     rl=fctnames(b,m,iun,z,iun,z,k0,individu)
     !!print*,"fin appel de la vraisamblance rl=",rl
     !stop
-    
+    !call intpr("derivaJ_scl 565", -1, m, 1)
     if(rl.eq.-1.d9) then
         rl=-1.d9
         goto 123
@@ -582,6 +568,12 @@
                     goto 123
                 end if    
         vl=(fcith(i)-vaux)/(2.d0*th)
+		
+		tail= size(v)
+		! call intpr(" ll pseudo-adpdative 1136", -1, ll, 1)
+		! call dblepr(" v pseudo-adpdative 1136", -1, vl, 1)
+		! call intpr(" tail pseudo-adpdative 1136", -1, tail, 1)
+		! call dblepr(" v(ll) pseudo-adpdative 1136", -1, v(ll), 1)
         v(ll)=vl
         do j=1,i
             k=k+1
@@ -590,24 +582,25 @@
     end do
 
 123   continue    
+	deallocate(fcith) ! scl_22-09-2017
     return
     
-    end subroutine derivaj
+    end subroutine derivaJ_scl
 !------------------------------------------------------------
 !                        SEARPAS
 !------------------------------------------------------------
 
 
-      subroutine searpasj(vw,step,b,bh,m,delta,fim,k0,fctnames,individu)
+      subroutine searpasj_scl(vw,step,b,bh,m,delta,fim,k0,fctnames,individu)
 !
 !  MINIMISATION UNIDIMENSIONNELLE
 !
       implicit none
     integer, intent(in)::individu ! indice de l'individu sur lequel on maximise la vraisemblance
       integer,intent(in)::m
-      double precision,dimension(m),intent(in)::b
+      double precision,dimension(m),intent(in)::b 
       double precision,intent(inout)::vw
-      double precision,dimension(m),intent(inout)::bh,delta
+      double precision,dimension(m),intent(inout)::bh,delta 
       double precision,intent(inout)::fim,step
       double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3
       double precision,dimension(2)::k0
@@ -617,8 +610,8 @@
 
        vlw1=dlog(vw)
        vlw2=vlw1+step
-       call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames,individu)
-       call valfpaj(vlw2,fi2,b,bh,m,delta,k0,fctnames,individu)
+       call valfpaj_scl(vlw1,fi1,b,bh,m,delta,k0,fctnames,individu)
+       call valfpaj_scl(vlw2,fi2,b,bh,m,delta,k0,fctnames,individu)
 
        if(fi2.ge.fi1) then
           vlw3=vlw2
@@ -628,7 +621,7 @@
           step=-step
 
           vlw1=vlw2+step
-          call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames,individu)
+          call valfpaj_scl(vlw1,fi1,b,bh,m,delta,k0,fctnames,individu)
           if(fi1.gt.fi2) goto 50
        else 
           vlw=vlw1
@@ -646,7 +639,7 @@
           fi2=fi1
 
           vlw1=vlw2+step
-          call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames,individu)
+          call valfpaj_scl(vlw1,fi1,b,bh,m,delta,k0,fctnames,individu)
           if(fi1.gt.fi2) goto 50
           if(fi1.eq.fi2) then
              fim=fi2
@@ -662,7 +655,7 @@
 !  CALCUL MINIMUM QUADRIQUE
 !
       vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))   
-      call valfpaj(vm,fim,b,bh,m,delta,k0,fctnames,individu)    
+      call valfpaj_scl(vm,fim,b,bh,m,delta,k0,fctnames,individu)    
       if(fim.le.fi2) goto 100
       vm=vlw2
       fim=fi2
@@ -671,13 +664,13 @@
       
       return
 
-      end subroutine searpasj
+      end subroutine searpasj_scl
 
 !------------------------------------------------------------
 !                         DCHOLE
 !------------------------------------------------------------
 
-      subroutine dcholej(a,k,nq,idpos)
+      subroutine dcholej_scl(a,k,nq,idpos)
 
       implicit none
       
@@ -786,10 +779,10 @@
       end do
 50    continue
       return
-      end subroutine dcholej
+      end subroutine dcholej_scl
 
 
-      subroutine dmfsdj(a,n,eps,ier)
+      subroutine dmfsdj_scl(a,n,eps,ier)
 !
 !   FACTORISATION DE CHOLESKY D'UNE MATRICE SDP
 !   MATRICE = TRANSPOSEE(T)*T
@@ -889,7 +882,7 @@
 12    ier=-1
       return
 
-      end subroutine dmfsdj
+      end subroutine dmfsdj_scl
 
 
 !------------------------------------------------------------
@@ -897,7 +890,7 @@
 !------------------------------------------------------------
 
 
-    subroutine dsinvj(A,N,EPS,IER)
+    subroutine dsinvj_scl(A,N,EPS,IER)
 
 !
 !     INVERSION D'UNE MATRICE SYMETRIQUE DEFINIE POSITIVE :
@@ -932,7 +925,7 @@
 !     A=TRANSPOSE(T) * T
 !
 
-    call dmfsdj(A,n,eps,ier)
+    call dmfsdj_scl(A,n,eps,ier)
       
 
 
@@ -1028,20 +1021,20 @@
 !     END OF ROW-AND MULTIPLICATION-LOOP
 !
 9     return
-      end subroutine dsinvj
+      end subroutine dsinvj_scl
 
 !------------------------------------------------------------
 !                          VALFPA
 !------------------------------------------------------------
 
-    subroutine valfpaj(vw,fi,b,bk,m,delta,k0,fctnames,individu)
+    subroutine valfpaj_scl(vw,fi,b,bk,m,delta,k0,fctnames,individu)
     
     implicit none
     
     integer, intent(in)::individu ! indice de l'individu sur lequel on maximise la vraisemblance
     integer,intent(in)::m  
     double precision,dimension(m),intent(in)::b,delta  
-    double precision,dimension(m),intent(out)::bk 
+    double precision,dimension(m),intent(out)::bk  
     double precision,intent(out)::fi 
     double precision::vw,fctnames,z    
     double precision,dimension(2)::k0
@@ -1060,17 +1053,17 @@
 1       continue
     return
     
-    end subroutine valfpaj
+    end subroutine valfpaj_scl
 
 !------------------------------------------------------------
 !                            MAXT
 !------------------------------------------------------------
-    subroutine dmaxt(maxt,delta,m)
+    subroutine dmaxt_scl(maxt,delta,m)
     
     implicit none
     
     integer,intent(in)::m
-    double precision,dimension(m),intent(in)::delta
+    double precision,dimension(m),intent(in)::delta 
     double precision,intent(out)::maxt
     integer::i 
     
@@ -1084,7 +1077,7 @@
     end do 
         
     return
-    end subroutine dmaxt
+    end subroutine dmaxt_scl
 
 
     end module optim_scl
