@@ -4,11 +4,12 @@
 !========================          funcpajng NEW         ====================
     double precision function funcpaGsplines(b,np,id,thi,jd,thj,k0)
 
+    !use comon,only:indictronq,indictronqdc,t0,t1,t0dc,t1dc,nz1,nz2
     use comon,only:m3m3,m2m2,m1m1,mmm,m3m2,m3m1,m3m,m2m1,m2m,m1m,mm3,mm2,mm1,mm,&
     im3,im2,im1,im,mm3dc,mm2dc,mm1dc,mmdc,im3dc,im2dc,im1dc,imdc,date,datedc,zi,&
-    t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,&
-    stra,ve,vedc,pe,effet,nz1,nz2,ng,g,nig,AG,indic_ALPHA,theta,alpha,&
-    auxig,aux1,aux2,res1,res3,indictronq,indictronqdc,resnonpen
+    c,cdc,nt0,nt1,nt0dc,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,&
+    stra,ve,vedc,pe,effet,ng,g,nig,AG,indic_ALPHA,theta,alpha,&
+    auxig,aux1,aux2,res1,res3,resnonpen
     use tailles
     use comongroup
     use residusM
@@ -17,7 +18,7 @@
 
     integer::nb,n,np,id,jd,i,j,k,vj,cptg,l,ig,choix
     integer,dimension(ngmax)::cpt
-    double precision::thi,thj,pe1,pe2,dnb,sum,inv,som1,som2,res,h1,int,gammaJ
+    double precision::thi,thj,pe1,pe2,dnb,sum,inv,som1,som2,res,h1,int,logGammaJ
     double precision,dimension(ngmax)::res2,res1dc,res2dc,res3dc
     double precision,dimension(np)::b,bh
     double precision,dimension(2)::k0
@@ -206,7 +207,7 @@
 
         res = 0.d0
         cptg = 0
-!     gam2 = gammaJ(inv)
+!     gam2 = logGammaJ(inv)
 ! k indice les groupes
 
         do k=1,ng
@@ -214,7 +215,7 @@
             if(cpt(k).gt.0)then
                 nb = nig(k)
                 dnb = dble(nig(k))
-!     gam1 = gammaJ(dnb + inv)
+!     gam1 = logGammaJ(dnb + inv)
                 if (dnb.gt.1.d0) then
                     do l=1,nb
                         sum=sum+dlog(1.d0+theta*dble(nb-l))
@@ -353,7 +354,7 @@
 ! ancienne vraisemblance : pour calendar sans vrai troncature cccccccc
                     res= res + res2(k) &
 !--      pour le deces:
-                    + res2dc(k)-gammaJ(1.d0/theta)-dlog(theta)/theta &
+                    + res2dc(k)-logGammaJ(1.d0/theta)-dlog(theta)/theta &
                     + dlog(integrale3(k))
                 else
 !*******************************************************
@@ -361,7 +362,7 @@
 !*******************************************************
 !        write(*,*)'******* TAYLOR *************'
                     res= res + res2(k)+ res2dc(k) &
-                    - gammaJ(1.d0/theta)-dlog(theta)/theta  &
+                    - logGammaJ(1.d0/theta)-dlog(theta)/theta  &
                     + dlog(integrale3(k)) 
                 endif
                 if ((res.ne.res).or.(abs(res).ge. 1.d30)) then
