@@ -5,11 +5,12 @@
     double precision function funcpaGsplines_log(b,np,id,thi,jd,thj,k0)
 
     use tailles
+    !use comon,only:kkapa,t0,t1,t0dc,t1dc
     use comon,only:m3m3,m2m2,m1m1,mmm,m3m2,m3m1,m3m,m2m1,m2m,m1m,mm3,mm2,mm1,mm,&
     im3,im2,im1,im,mm3dc,mm2dc,mm1dc,mmdc,im3dc,im2dc,im1dc,imdc,date,datedc,zi,&
-    t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst, &
+    c,cdc,nt0,nt1,nt0dc,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst, &
     effet,stra,ve,vedc,pe,ng,g,nig,AG,indic_ALPHA,ALPHA,sig2, &
-    auxig,aux1,aux2,res1,res3,res5,kkapa,resnonpen,indictronq
+    auxig,aux1,aux2,res1,res3,res5,resnonpen,indictronq
     use residusM
     use comongroup
 
@@ -367,7 +368,7 @@
 !                   write(*,*)'************** TAYLOR *************'
                 !    res= res + res2(k) &
                 !    + res2dc(k)  &
-                !    - gammaJ(1./theta)-dlog(theta)/theta  &
+                !    - logGammaJ(1./theta)-dlog(theta)/theta  &
                 !    + dlog(integrale3(k))
                 !endif
                 if ((res.ne.res).or.(abs(res).ge. 1.d30)) then
