@@ -4,10 +4,11 @@
 !========================          funcpajng NEW         ====================
     double precision function funcpaGweib_intcens(b,np,id,thi,jd,thj,k0)
 
+    !use comon,only:indictronqdc
     use comon,only:etaR,etaD,betaR,betaD, &
     t0,t1,tU,t0dc,t1dc,c,cdc,nsujet,nva,nva1,nva2,nst,&
     stra,ve,vedc,effet,ng,g,nig,AG,indic_ALPHA,theta,alpha,&
-    auxig,aux1,aux2,res1,res3,indictronq,indictronqdc,resL,resU,kkapa
+    auxig,aux1,aux2,res1,res3,indictronq,resL,resU,kkapa
     use tailles
     use comongroup
     use residusM
@@ -16,7 +17,7 @@
 
     integer::nb,n,np,id,jd,i,j,k,vj,cptg,l,ig,choix
     integer,dimension(ngmax)::cpt
-    double precision::thi,thj,dnb,sum,inv,res,int,gammaJ
+    double precision::thi,thj,dnb,sum,inv,res,int,logGammaJ
     double precision,dimension(ngmax)::res2,res1dc,res2dc,res3dc
     double precision,dimension(np)::b,bh
     double precision,dimension(2)::k0
@@ -126,7 +127,7 @@
 
         res = 0.d0
         cptg = 0
-!     gam2 = gammaJ(inv)
+!     gam2 = logGammaJ(inv)
 ! k indice les groupes
 
         do k=1,ng
@@ -134,7 +135,7 @@
             if(cpt(k).gt.0)then
                 nb = nig(k)
                 dnb = dble(nig(k))
-!     gam1 = gammaJ(dnb + inv)
+!     gam1 = logGammaJ(dnb + inv)
                 if (dnb.gt.1.d0) then
                     do l=1,nb
                         sum=sum+dlog(1.d0+theta*dble(nb-l))
@@ -293,7 +294,7 @@
                     dlog(integrale1(k)) - dlog(integrale2(k))
                 else
                     res = res + res2dc(k) - &
-                    gammaJ(1.d0/theta)-dlog(theta)/theta + &
+                    logGammaJ(1.d0/theta)-dlog(theta)/theta + &
                     dlog(integrale1(k))
                 endif
 
